@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 from requests import Request, Session
+import sys
+sys.path.append( '.\\seams\\' )
 from seams.exceptions import SeamsException, SeamsAPIException
+import json
 
 class Seams(object):
     '''
@@ -148,7 +151,6 @@ class Seams(object):
         :returns:
             JSON formatted vertex with the updates
         '''
-
         body = self.__properties_formatter(vertex_label, attributes)
         try:
             response = self.__http_request(self.bearer, 'PUT', '{}/tenant/{}/vertex/update/{}'.format(self.URL, tenant_id, vertex_id), content='application/json', data=body)
@@ -396,12 +398,11 @@ class Seams(object):
         '''
         Private helper function that formats a list of key value pairs for properties on a vertex
         '''
-        
-        properties = []
-        for arg in args:
-            properties.append('"{}": "{}"'.format(arg, args[arg]))
-        finalStr = ','.join(properties)
-        return '{{"vertexLabel": "{}","properties": {{{}}}}}'.format(vertex_label, finalStr)
+        for item in args:
+            if item != 'status':
+                if isinstance(args[item], list):
+                    args[item] = json.dumps(args[item])
+        return '{{"vertexLabel": "{}", "properties": {}}}'.format(vertex_label, json.dumps(args))
 
 
     def __http_request(self, 
